@@ -739,7 +739,7 @@ gaussian_sim <- function(trial_reps=100, subj_per_arm, a0_vals, effect_vals,
     #Create an list of results and apply the bayes_ctd_array class to the list, then
     # return the output object.
     class_out <- list(data = output, subj_per_arm = subj_per_arm, a0_vals = a0_vals, effect_vals = effect_vals, rand_control_diff = rand_control_diff, objtype= 'historic')
-    class(class_out) <- append(class(class_out), "bayes_ctd_array")
+    class(class_out) <- append("bayes_ctd_array", class(class_out))
     return(class_out)
 
 }
@@ -1182,7 +1182,7 @@ simple_gaussian_sim <- function(trial_reps=100, subj_per_arm, effect_vals, mu1_v
     #Create an list of results and apply the bayes_ctd_array class to the list, then
     # return the output object.
     class_out <- list(data = output, subj_per_arm = subj_per_arm, a0_vals = 0, effect_vals = effect_vals, rand_control_diff = 1, objtype= 'simple')
-    class(class_out) <- append(class(class_out), "bayes_ctd_array")
+    class(class_out) <- append("bayes_ctd_array", class(class_out))
     return(class_out)
 
 }
